@@ -5,7 +5,6 @@ import (
 	"testing"
 	"time"
 
-	cache_ "github.com/jandedobbeleer/oh-my-posh/src/cache/mock"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
@@ -53,15 +52,15 @@ func TestBrewfatherSegment(t *testing.T) {
 	batchReadingJSON3 := `,"type":"manual"}, {"id":"manual","temp":15,"comment":"","sg":1.050,"time":`
 
 	cases := []struct {
+		Error                     error
 		Case                      string
 		BatchJSONResponse         string
 		BatchReadingsJSONResponse string
 		ExpectedString            string
-		ExpectedEnabled           bool
-		CacheTimeout              int
-		CacheFoundFail            bool
 		Template                  string
-		Error                     error
+		CacheTimeout              int
+		ExpectedEnabled           bool
+		CacheFoundFail            bool
 	}{
 		{
 			Case:                      "Planning Status",
@@ -148,35 +147,27 @@ func TestBrewfatherSegment(t *testing.T) {
 	for _, tc := range cases {
 		env := &mock.Environment{}
 		props := properties.Map{
-			properties.CacheTimeout: tc.CacheTimeout,
-			BFBatchID:               BFFakeBatchID,
-			APIKey:                  "FAKE",
-			BFUserID:                "FAKE",
+			BFBatchID: BFFakeBatchID,
+			APIKey:    "FAKE",
+			BFUserID:  "FAKE",
 		}
 
-		cache := &cache_.Cache{}
-		cache.On("Get", BFCacheKey).Return(nil, false) // cache testing later because cache is a little more complicated than just the single response.
-		// cache.On("Set", BFCacheKey, tc.JSONResponse, tc.CacheTimeout).Return()
-
 		env.On("HTTPRequest", BFBatchURL).Return([]byte(tc.BatchJSONResponse), tc.Error)
 		env.On("HTTPRequest", BFBatchReadingsURL).Return([]byte(tc.BatchReadingsJSONResponse), tc.Error)
-		env.On("Cache").Return(cache)
 		env.On("Flags").Return(&runtime.Flags{})
 
-		ns := &Brewfather{
-			props: props,
-			env:   env,
-		}
+		brew := &Brewfather{}
+		brew.Init(props, env)
 
-		enabled := ns.Enabled()
+		enabled := brew.Enabled()
 		assert.Equal(t, tc.ExpectedEnabled, enabled, tc.Case)
 		if !enabled {
 			continue
 		}
 
 		if tc.Template == "" {
-			tc.Template = ns.Template()
+			tc.Template = brew.Template()
 		}
-		assert.Equal(t, tc.ExpectedString, renderTemplate(env, tc.Template, ns), tc.Case)
+		assert.Equal(t, tc.ExpectedString, renderTemplate(env, tc.Template, brew), tc.Case)
 	}
 }
